@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4008';
+our $VERSION = '0.4009';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -141,7 +141,9 @@ has double_dotted_onetwentyeighth => (is => 'ro', default => sub { 'ddzn' });
 
 sub note {
     my ($self, @spec) = @_;
-    $self->counter( $self->counter + dura_size($spec[0]) );
+    my $size = $spec[0] =~ /^d(\d+)$/ ? $1 / TICKS : dura_size($spec[0]);
+    #warn __PACKAGE__,' L',__LINE__,' ',,"$spec[0] => $size\n";
+    $self->counter( $self->counter + $size );
     return $self->score->n(@spec);
 }
 
@@ -158,7 +160,9 @@ sub accent_note {
 
 sub rest {
     my ($self, @spec) = @_;
-    $self->counter( $self->counter + dura_size($spec[0]) );
+    my $size = $spec[0] =~ /^d(\d+)$/ ? $1 / TICKS : dura_size($spec[0]);
+    #warn __PACKAGE__,' L',__LINE__,' ',,"$spec[0] => $size\n";
+    $self->counter( $self->counter + $size );
     return $self->score->r(@spec);
 }
 
@@ -599,7 +603,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4008
+version 0.4009
 
 =head1 SYNOPSIS
 
@@ -921,8 +925,8 @@ If not provided the B<snare> is used for the B<grace> and B<patch>
 patches.  Also, 1/2 of the score volume is used for the B<accent>
 if that is not given.
 
-If the B<grace> note is given as a literal C<'r'>, rest instead adding
-a note to the score.
+If the B<grace> note is given as a literal C<'r'>, rest instead of
+adding a note to the score.
 
 =head2 roll
 
